##  Exporting PII Change Data
  1. Go to the administration and navigate to Users.
  2. Select the user whose PII change history you want to review.
  3. Go to the PII Change Audit Report tab.
![<alt>The PII Change Audit Report tab on the Edit User page where you configure the reports time range and start the export.</alt>](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiocfde6cc3fe2f467e8f1a02be850c12f0_HiRes.png)
  4. Select a Start Date and End Date.
If you don't select dates, the default time frame is the last 30 days.
  5. Click New Report. Remain on the page until you see the success message that the report is completed. Then the file download starts automatically. Alternatively, you can leave the page to receive an email notification with the download link later.
